Contributing
============

Pull requests are more than welcome — both to the library and to the
documentation. Some useful information:

- We aim to follow PEP 8 in the library, but ignoring the
  79-character-per-line limit, instead following a soft limit of 99,
  but allowing lines over this where it is the readable thing to do.

- We aim to follow PEP 257 for all docstrings, and make them properly
  parseable by Sphinx while generating API documentation.

- We keep ``pyflakes`` reporting no errors or warnings at all times.

- We keep the master branch passing all tests at all times on all
  supported versions.